@@ -429,7 +429,7 @@ def to_avro_abris_config(config_map, topic, is_key):
         .usingSchemaRegistry(scala_map)
 
 
-def instanciate_delta_table(spark_session: SparkSession, spark_job_conf: dict, table_name: str):
+def instantiate_delta_table(spark_session: SparkSession, spark_job_conf: dict, table_name: str):
     table_conf = get_spark_conf(table_name, spark_job_conf['outputs'])
     create_delta_tables_if_not_exists(table_conf, table_conf['delta_options']['schema'])
     return DeltaTable.forPath(spark_session, table_conf['delta_options']['location'])
